traitlets: Traitlets Python configuration system
================================================

Description
-----------

Traitlets Python configuration system

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/traitlets/

